##  Context
Provisioning through SAP for Me allows you to manage various SAP environments and products from a unified, centralized dashboard. This simplifies management and removes the need to navigate multiple platforms. This guide explains the steps to provision SAP LeanIX workspaces using SAP for Me.
